# Wagtailnest - a RESTful Wagtail enclosure

[![PyPI](https://img.shields.io/pypi/pyversions/wagtailnest.svg)](https://pypi.org/project/wagtailnest/)
[![PyPI](https://img.shields.io/pypi/v/wagtailnest.svg)](https://pypi.org/project/wagtailnest/)

This application serves as a wrapper around Wagtail and Django Rest Framework

It provides reasonable defaults for a minimal environment
